@@ -104,10 +104,9 @@ class Line:
 
         Border case: One function only
 
-        >>> same_as_first = Pipeline(first)
+        >>> same_as_first = Line(first)
         >>> assert same_as_first(42) == first(42)
 
-
         >>> from functools import partial
         >>> pipe = Line(sum, str, print, pipeline_name='MyPipeline', input_name='x', output_name='y')
         >>> pipe
@@ -315,7 +314,7 @@ def stack(*funcs):
 
 
 # TODO: Need tests and the new args of Line (named_funcs...)
-class LayeredPipeline(Pipeline):
+class LayeredPipeline(Line):
     def __init__(self, *funcs: LayeredFuncs, pipeline_name=None):
         def _funcs():
             for func in funcs:
@@ -384,7 +383,7 @@ def mk_multi_func(named_funcs_dict: Optional[Dict] = None, /, **named_funcs) ->
     >>> multi_featurizer = mk_multi_func(**featurizers)
     >>> multi_featurizer({'a': 3, 'b': 12})
     {'a': '3', 'b': [12, 12, 12]}
-    >>> my_pipe = Pipeline(multi_chunker, multi_featurizer)
+    >>> my_pipe = Line(multi_chunker, multi_featurizer)
     >>> my_pipe({'a': (1, 2), 'b': (3, 4)})
     {'a': '(1, 2)', 'b': [(3, 4), (3, 4), (3, 4)]}
     """
